package com.fs.course.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.course.domain.FsCourseFinishTempParent;

/**
 * 完课模板Mapper接口
 * 
 * @author 吴树波
 * @date 2025-05-22
 */
public interface FsCourseFinishTempParentMapper extends BaseMapper<FsCourseFinishTempParent>{
    /**
     * 查询完课模板
     * 
     * @param id 完课模板主键
     * @return 完课模板
     */
    FsCourseFinishTempParent selectFsCourseFinishTempParentById(Long id);

    /**
     * 查询完课模板列表
     * 
     * @param fsCourseFinishTempParent 完课模板
     * @return 完课模板集合
     */
    List<FsCourseFinishTempParent> selectFsCourseFinishTempParentList(FsCourseFinishTempParent fsCourseFinishTempParent);

    /**
     * 新增完课模板
     * 
     * @param fsCourseFinishTempParent 完课模板
     * @return 结果
     */
    int insertFsCourseFinishTempParent(FsCourseFinishTempParent fsCourseFinishTempParent);

    /**
     * 修改完课模板
     * 
     * @param fsCourseFinishTempParent 完课模板
     * @return 结果
     */
    int updateFsCourseFinishTempParent(FsCourseFinishTempParent fsCourseFinishTempParent);

    /**
     * 删除完课模板
     * 
     * @param id 完课模板主键
     * @return 结果
     */
    int deleteFsCourseFinishTempParentById(Long id);

    /**
     * 批量删除完课模板
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteFsCourseFinishTempParentByIds(Long[] ids);
}
